#
# spec file for package nulloy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without vlc
%bcond_without taglib

#https://github.com/nulloy/nulloy/archive/refs/tags/0.9.5.tar.gz

Name:           nulloy
Version:        0.9.7
Release:        1.12
Summary:        Music player with a Waveform Progress Bar
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            http://nulloy.com
Source:         https://github.com/nulloy/nulloy/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         0001-taglib-2.0-compatibility.patch
Patch1:         0001-playbackEngineVlc-build-fix.patch
BuildRequires:  clang
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  zip
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
%if %{with vlc}
BuildRequires:  pkgconfig(libvlc)
Recommends:     %{name}-vlc
%endif
%if %{with taglib}
BuildRequires:  pkgconfig(taglib)
Recommends:     %{name}-taglib
%endif
Recommends:     %{name}-gstreamer
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Nulloy is a opensource, simple and clean music player with a Waveform
Progressbar. It is written in C++ using QT.

%if %{with taglib}
%package taglib
Summary:        Taglib plugin for %{name}
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}

%description taglib
This package contains the taglib plugin for %{name} - a music player
with a Waveform Progressbar.
%endif

%package gstreamer
Summary:        Gstreamer plugin for %{name}
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}
Recommends:     gstreamer-plugins-good

%description gstreamer
This package contains the gstreamer playback plugin for %{name} - a lightweight
music player with a Waveform Progressbar.

%if %{with vlc}
%package vlc
Summary:        VLC plugin for %{name}
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}

%description vlc
This package contains the vlc playback plugin for %{name} - a lightweight
music player with a Waveform Progressbar.
%endif

%prep
%setup -qn %{name}-%{version}
%autopatch -p1

%build
# -Wno-error=return-type
# This is not an autotools configure

CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags} -Wno-error=return-type" \
QMAKE=%{_libdir}/qt5/bin/qmake \
LRELEASE=lrelease-qt5 \
./configure \
	--no-update-check \
	--prefix %{_prefix} \
%if %{with vlc}
	--vlc \
%endif
%if %{with taglib}
	--gstreamer-tagreader \
%else
	--no-taglib \
%endif
	--libdir "%{_lib}"

make %{?_smp_mflags}

%install
CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags}" \
QMAKE=qmake-qt5 \
LRELEASE=lrelease-qt5 \
./configure \
	--no-update-check \
	--prefix %{buildroot}%{_prefix} \
%if %{with vlc}
	--vlc \
%endif
%if %{with taglib}
	--gstreamer-tagreader \
%else
	--no-taglib \
%endif
	--libdir "%{_lib}"

%makeinstall
#cp -v .tmp/nulloy.svg %{buildroot}%{_datadir}/icons/hicolor/*/apps/
%suse_update_desktop_file %{name}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog THANKS
%license LICENSE.GPL3
%{_bindir}/nulloy
%{_datadir}/applications/nulloy.desktop
%{_datadir}/icons/hicolor/*/apps/nulloy.svg
%{_datadir}/nulloy
%dir %{_libdir}/nulloy
%dir %{_libdir}/nulloy/plugins

%if %{with taglib}
%files taglib
%defattr(-,root,root)
%{_libdir}/nulloy/plugins/libplugin_taglib.so
%endif

%files gstreamer
%defattr(-,root,root)
%{_libdir}/nulloy/plugins/libplugin_gstreamer.so

%if %{with vlc}
%files vlc
%defattr(-,root,root)
%{_libdir}/nulloy/plugins/libplugin_vlc.so
%endif

%changelog
* Wed Feb  7 2024 Dave Plater <davejplater@gmail.com>
- Update to v0.9.7
- Fix vlc plugin build failure with patch from git:
  0001-playbackEngineVlc-build-fix.patch
- Fix taglib plugin build with 0001-taglib-2.0-compatibility.patch
- Upstream changes:
  * Playback speed control
  * Automatically saving settings and playlist in case of a crash
  * More customizable keyboard shortcuts (Open Tag Editor,
  Move to Trash, etc)
  * Packaging .AppImage for Linux
  * New "Scroll to item" playlist option
  * Many other minor bug fixes and improvements
* Mon Jul  4 2022 Dave Plater <davejplater@gmail.com>
- Update to v0.9.5
- Remove incorporated patch reproducible.patch
- Remove unneeded patch nulloy-QPainterPath-patch
- Upstream changes:
  * Tag editor
  * Notify about new version once
  * Other minor bug fixes
* Sat Jun  6 2020 Dave Plater <davejplater@gmail.com>
- Update to snapshot 0.8.2.pre61qt5.9b036e and fix qt5.15 build
  with nulloy-QPainterPath-patch see:
  https://github.com/nulloy/nulloy/issues/156
- Remove incorporated patches:
  0001-configurable-library-directory.patch,
  0001-vlc-phonon-plugins-update.patch and
  0001-pkg_check_lib-fix.patch
- Upstream changes beside patches:
  * Fix LIBDIR variable reference
* Wed Nov  6 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make zip timestamps reproducible (boo#1134568)
* Tue Sep 17 2019 Dave Plater <davejplater@gmail.com>
- Fix Factory build with -isystem pointing to phonon4qt5 include
  directory.
* Sat May 18 2019 plater <davejplater@gmail.com>
- Removed fix-library-directory.patch and replaced with modified
  patch from git 0001-configurable-library-directory.patch.
- Removed unneeded build conditonals for phonon and vlc.
* Tue May  7 2019 plater <davejplater@gmail.com>
-  Fix vlc plugin build with 0001-vlc-phonon-plugins-update.patch
- Add 0001-pkg_check_lib-fix.patch from git.
* Sun May  5 2019 Jan Engelhardt <jengelh@inai.de>
- Remove %%if..%%endif guards that do not affect the build result.
* Thu May  2 2019 plater <davejplater@gmail.com>
- Update to 0.8.2.pre61qt5 git snapshot to build with qt5
- Rebased fix-library-directory.patch
* Fri Apr 15 2016 rpm@fthiessen.de
- Updated to 0.8.2:
  * Chinese translation
  * Fix: tags encoding doesn't apply to playlist
  * Other minor bug fixes and improvements
* Sat Jan 30 2016 rpm@fthiessen.de
- Updated to 0.8.1:
  * Fixed phonon plugin
  * Added Spanish, Ukrainian and Lithuanian translations
  * Setting tags encoding
  * Fixed vlc plugin
  * Some other fixes and improvements
- Build phonon plugin
- Removed upstream fixed fix-upstream-desktop.patch,
  fix-upstream-gstreamer-encoding-error.patch and
  fix-upstream-handle-flags.patch
- Renamed fix-libsuffix.patch to fix-library-directory.patch
  and rebased it.
* Thu Nov  5 2015 rpm@fthiessen.de
- Added fix-libsuffix.patch to install plugins in lib64 on x86_64.
* Wed Oct 28 2015 rpm@fthiessen.de
- Split taglib and gstreamer plugins into subpackages
* Tue Oct 27 2015 rpm@fthiessen.de
- Wrote own spec file, replaced obs-service.
- Update to version 0.8
  * Added fix-upstream-desktop.patch to get rid of warning about
    invalid tags in .desktop file.
  * Added fix-upstream-gstreamer-encoding-error.patch
  * Added fix-upstream-handle-flags.patch to make qmake recognize
    optimization flags, so we can pass out RPM_OPT_FLAGS to it.
  * Added fix-upstream-gstreamer-encoding-error.patch:
    Fixes encoding with gstreamer, fixed upstream in git a2fc81a
    Can be removed next upstream release.
